@@ -29,7 +29,7 @@
 #' 
 #' data(Skulls)
 #' sk.rmod <- robmlm(cbind(mb, bh, bl, nh) ~ epoch, data=Skulls)
-#' plot(sk.rmod, col=Skulls$epoch)
+#' plot(sk.rmod, col=Skulls$epoch, segments=TRUE)
 #' axis(side=3, at=15+seq(0,120,30), labels=levels(Skulls$epoch), cex.axis=1)
 #' 
 #' # Pottery data
@@ -71,7 +71,7 @@ plot.robmlm <-
 	n <- length(weights)
 	ind <- 1:n
 	bad <- weights < id.weight
-	text(ind[bad], weights[bad], labels[bad], pos = id.pos, xpd=TRUE)
+	if(sum(bad) > 0) text(ind[bad], weights[bad], labels[bad], pos = id.pos, xpd=TRUE)
 	
 	if(segments)
 		segments(1:n, 1, 1:n, weights, col=col)
